@@ -52,6 +52,14 @@ get_builtin_columns (void)
                                            "description", _("The size of the file."),
                                            "xalign", 1.0,
                                            NULL));
+    columns = g_list_append (columns,
+                             g_object_new (CAJA_TYPE_COLUMN,
+                                           "name", "size_on_disk",
+                                           "attribute", "size_on_disk",
+                                           "label", _("Size on Disk"),
+                                           "description", _("The size of the file on disk."),
+                                           "xalign", 1.0,
+                                           NULL));
     columns = g_list_append (columns,
                              g_object_new (CAJA_TYPE_COLUMN,
                                            "name", "type",
