@@ -70,11 +70,7 @@ enum
     NUM_COLUMNS
 };
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 G_DEFINE_TYPE (CajaMimeApplicationChooser, caja_mime_application_chooser, GTK_TYPE_BOX);
-#else
-G_DEFINE_TYPE (CajaMimeApplicationChooser, caja_mime_application_chooser, GTK_TYPE_VBOX);
-#endif
 
 static void refresh_model             (CajaMimeApplicationChooser *chooser);
 static void refresh_model_soon        (CajaMimeApplicationChooser *chooser);
@@ -380,19 +376,15 @@ caja_mime_application_chooser_init (CajaMimeApplicationChooser *chooser)
     chooser->details = g_new0 (CajaMimeApplicationChooserDetails, 1);
 
     chooser->details->for_multiple_files = FALSE;
-#if GTK_CHECK_VERSION (3, 0, 0)
+
     gtk_orientable_set_orientation (GTK_ORIENTABLE (chooser), GTK_ORIENTATION_VERTICAL);
-#endif
+
     gtk_container_set_border_width (GTK_CONTAINER (chooser), 8);
     gtk_box_set_spacing (GTK_BOX (chooser), 0);
     gtk_box_set_homogeneous (GTK_BOX (chooser), FALSE);
 
     chooser->details->label = gtk_label_new ("");
-#if GTK_CHECK_VERSION (3, 16, 0)
     gtk_label_set_xalign (GTK_LABEL (chooser->details->label), 0);
-#else
-    gtk_misc_set_alignment (GTK_MISC (chooser->details->label), 0.0, 0.5);
-#endif
     gtk_label_set_line_wrap (GTK_LABEL (chooser->details->label), TRUE);
     gtk_label_set_line_wrap_mode (GTK_LABEL (chooser->details->label),
                                   PANGO_WRAP_WORD_CHAR);
@@ -408,6 +400,7 @@ caja_mime_application_chooser_init (CajaMimeApplicationChooser *chooser)
                                     GTK_POLICY_AUTOMATIC);
     gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolled),
                                          GTK_SHADOW_IN);
+    gtk_scrolled_window_set_overlay_scrolling (GTK_SCROLLED_WINDOW (scrolled), FALSE);
 
     gtk_widget_show (scrolled);
     gtk_box_pack_start (GTK_BOX (chooser), scrolled, TRUE, TRUE, 6);
@@ -418,11 +411,7 @@ caja_mime_application_chooser_init (CajaMimeApplicationChooser *chooser)
     gtk_container_add (GTK_CONTAINER (scrolled),
                        chooser->details->treeview);
 
-#if GTK_CHECK_VERSION(3, 0, 0)
     box = gtk_button_box_new (GTK_ORIENTATION_HORIZONTAL);
-#else
-    box = gtk_hbutton_box_new ();
-#endif
     gtk_box_set_spacing (GTK_BOX (box), 6);
     gtk_button_box_set_layout (GTK_BUTTON_BOX (box), GTK_BUTTONBOX_END);
     gtk_box_pack_start (GTK_BOX (chooser), box, FALSE, FALSE, 6);
