@@ -387,7 +387,6 @@ create_emblem_widget_with_pixbuf (CajaEmblemSidebar *emblem_sidebar,
     GtkWidget *image, *event_box;
     GdkPixbuf *prelight_pixbuf;
 
-
     image = eel_labeled_image_new (display_name, pixbuf);
 
     eel_labeled_image_set_fixed_image_height (EEL_LABELED_IMAGE (image),
@@ -450,7 +449,7 @@ create_emblem_widget (CajaEmblemSidebar *emblem_sidebar,
     GdkPixbuf *pixbuf;
     CajaIconInfo *info;
 
-    info = caja_icon_info_lookup_from_name (name, CAJA_ICON_SIZE_STANDARD);
+    info = caja_icon_info_lookup_from_name (name, CAJA_ICON_SIZE_STANDARD, 1);
 
     pixbuf = caja_icon_info_get_pixbuf_at_size (info, CAJA_ICON_SIZE_STANDARD);
 
