@@ -141,12 +141,8 @@ append_label (GtkWidget *vbox,
 
     label = gtk_label_new (NULL);
     gtk_label_set_markup (GTK_LABEL (label), str);
-#if GTK_CHECK_VERSION (3, 16, 0)
     gtk_label_set_xalign (GTK_LABEL (label), 0);
     gtk_label_set_yalign (GTK_LABEL (label), 0);
-#else
-    gtk_misc_set_alignment (GTK_MISC (label), 0, 0);
-#endif
     gtk_label_set_selectable (GTK_LABEL (label), TRUE);
 
     /* setting can_focus to FALSE will allow to make the label
