@@ -63,11 +63,15 @@
 
 static void                  schedule_refresh_go_menu                      (CajaNavigationWindow   *window);
 
+
 static void
 action_close_all_windows_callback (GtkAction *action,
                                    gpointer user_data)
 {
-    caja_application_close_all_navigation_windows ();
+    CajaApplication *app;
+
+    app = CAJA_APPLICATION (g_application_get_default ());
+    caja_application_close_all_navigation_windows (app);
 }
 
 static gboolean
@@ -610,7 +614,6 @@ action_new_window_callback (GtkAction *action,
     current_window = CAJA_WINDOW (user_data);
     new_window = caja_application_create_navigation_window (
                      current_window->application,
-                     NULL,
                      gtk_window_get_screen (GTK_WINDOW (current_window)));
     caja_window_go_home (new_window);
 }
