@@ -75,7 +75,7 @@ struct _ButtonData
     unsigned int file_changed_signal_id;
 
     /* custom icon */
-    GdkPixbuf *custom_icon;
+    cairo_surface_t *custom_icon;
 
     /* flag to indicate its the base folder in the URI */
     gboolean is_base_dir;
@@ -206,8 +206,10 @@ trash_state_changed_cb (CajaTrashMonitor *monitor,
 {
     GFile *file;
     GList *list;
+    gint scale;
 
     file = g_file_new_for_uri ("trash:///");
+    scale = gtk_widget_get_scale_factor (GTK_WIDGET (path_bar));
     for (list = path_bar->button_list; list; list = list->next)
     {
         ButtonData *button_data;
@@ -216,12 +218,12 @@ trash_state_changed_cb (CajaTrashMonitor *monitor,
         {
             GIcon *icon;
             CajaIconInfo *icon_info;
-            GdkPixbuf *pixbuf;
+            cairo_surface_t *surface;
 
             icon = caja_trash_monitor_get_icon ();
-            icon_info = caja_icon_info_lookup (icon, CAJA_PATH_BAR_ICON_SIZE);
-            pixbuf = caja_icon_info_get_pixbuf_at_size (icon_info, CAJA_PATH_BAR_ICON_SIZE);
-            gtk_image_set_from_pixbuf (GTK_IMAGE (button_data->image), pixbuf);
+            icon_info = caja_icon_info_lookup (icon, CAJA_PATH_BAR_ICON_SIZE, scale);
+            surface = caja_icon_info_get_surface_at_size (icon_info, CAJA_PATH_BAR_ICON_SIZE);
+            gtk_image_set_from_surface (GTK_IMAGE (button_data->image), surface);
         }
     }
     g_object_unref (file);
@@ -1339,25 +1341,30 @@ button_clicked_cb (GtkWidget *button,
 static CajaIconInfo *
 get_type_icon_info (ButtonData *button_data)
 {
+    gint icon_scale = gtk_widget_get_scale_factor (GTK_WIDGET (button_data->button));
+
     switch (button_data->type)
     {
     case ROOT_BUTTON:
         return caja_icon_info_lookup_from_name (CAJA_ICON_FILESYSTEM,
-                                                CAJA_PATH_BAR_ICON_SIZE);
+                                                CAJA_PATH_BAR_ICON_SIZE,
+                                                icon_scale);
 
     case HOME_BUTTON:
         return caja_icon_info_lookup_from_name (CAJA_ICON_HOME,
-                                                CAJA_PATH_BAR_ICON_SIZE);
+                                                CAJA_PATH_BAR_ICON_SIZE,
+                                                icon_scale);
 
     case DESKTOP_BUTTON:
         return caja_icon_info_lookup_from_name (CAJA_ICON_DESKTOP,
-                                                CAJA_PATH_BAR_ICON_SIZE);
+                                                CAJA_PATH_BAR_ICON_SIZE,
+                                                icon_scale);
 
     case NORMAL_BUTTON:
         if (button_data->is_base_dir)
         {
             return caja_file_get_icon (button_data->file,
-                                       CAJA_PATH_BAR_ICON_SIZE,
+                                       CAJA_PATH_BAR_ICON_SIZE, icon_scale,
                                        CAJA_FILE_ICON_FLAGS_NONE);
         }
 
@@ -1375,7 +1382,7 @@ button_data_free (ButtonData *button_data)
     g_free (button_data->dir_name);
     if (button_data->custom_icon)
     {
-        g_object_unref (button_data->custom_icon);
+        cairo_surface_destroy (button_data->custom_icon);
     }
     if (button_data->file != NULL)
     {
@@ -1440,7 +1447,7 @@ static void
 caja_path_bar_update_button_appearance (ButtonData *button_data)
 {
     CajaIconInfo *icon_info;
-    GdkPixbuf *pixbuf;
+    cairo_surface_t *surface;
     const gchar *dir_name = get_dir_name (button_data);
 
     if (button_data->label != NULL)
@@ -1467,27 +1474,27 @@ caja_path_bar_update_button_appearance (ButtonData *button_data)
     {
         if (button_data->custom_icon)
         {
-            gtk_image_set_from_pixbuf (GTK_IMAGE (button_data->image), button_data->custom_icon);
+            gtk_image_set_from_surface (GTK_IMAGE (button_data->image), button_data->custom_icon);
             gtk_widget_show (GTK_WIDGET (button_data->image));
         }
         else
         {
             icon_info = get_type_icon_info (button_data);
-            pixbuf = NULL;
+            surface = NULL;
 
             if (icon_info != NULL)
             {
-                pixbuf = caja_icon_info_get_pixbuf_at_size (icon_info, CAJA_PATH_BAR_ICON_SIZE);
+                surface = caja_icon_info_get_surface_at_size (icon_info, CAJA_PATH_BAR_ICON_SIZE);
                 g_object_unref (icon_info);
             }
 
-            if (pixbuf != NULL)
+            if (surface != NULL)
             {
-                gtk_image_set_from_pixbuf (GTK_IMAGE (button_data->image), pixbuf);
+                gtk_image_set_from_surface (GTK_IMAGE (button_data->image), surface);
                 gtk_style_context_add_class (gtk_widget_get_style_context (button_data->button),
                                              "image-button");
                 gtk_widget_show (GTK_WIDGET (button_data->image));
-                g_object_unref (pixbuf);
+                cairo_surface_destroy (surface);
             }
             else
             {
@@ -1529,10 +1536,16 @@ setup_file_path_mounted_mount (GFile *location, ButtonData *button_data)
     GIcon *icon;
     CajaIconInfo *info;
     GFile *root, *default_location;
+    gint scale;
 
+    /* Return false if button has not been set up yet or has been destroyed*/
+    if (!button_data->button)
+        return FALSE;
     result = FALSE;
     volume_monitor = g_volume_monitor_get ();
     mounts = g_volume_monitor_get_mounts (volume_monitor);
+
+    scale = gtk_widget_get_scale_factor (GTK_WIDGET (button_data->button));
     for (l = mounts; l != NULL; l = l->next)
     {
         mount = l->data;
@@ -1556,9 +1569,9 @@ setup_file_path_mounted_mount (GFile *location, ButtonData *button_data)
                 {
                     icon = g_themed_icon_new (CAJA_ICON_FOLDER);
                 }
-                info = caja_icon_info_lookup (icon, CAJA_PATH_BAR_ICON_SIZE);
+                info = caja_icon_info_lookup (icon, CAJA_PATH_BAR_ICON_SIZE, scale);
                 g_object_unref (icon);
-                button_data->custom_icon = caja_icon_info_get_pixbuf_at_size (info, CAJA_PATH_BAR_ICON_SIZE);
+                button_data->custom_icon = caja_icon_info_get_surface_at_size (info, CAJA_PATH_BAR_ICON_SIZE);
                 g_object_unref (info);
                 button_data->dir_name = g_mount_get_name (mount);
                 button_data->type = MOUNT_BUTTON;
@@ -1580,9 +1593,9 @@ setup_file_path_mounted_mount (GFile *location, ButtonData *button_data)
                 {
                     icon = g_themed_icon_new (CAJA_ICON_FOLDER);
                 }
-                info = caja_icon_info_lookup (icon, CAJA_PATH_BAR_ICON_SIZE);
+                info = caja_icon_info_lookup (icon, CAJA_PATH_BAR_ICON_SIZE, scale);
                 g_object_unref (icon);
-                button_data->custom_icon = caja_icon_info_get_pixbuf_at_size (info, CAJA_PATH_BAR_ICON_SIZE);
+                button_data->custom_icon = caja_icon_info_get_surface_at_size (info, CAJA_PATH_BAR_ICON_SIZE);
                 g_object_unref (info);
                 button_data->type = DEFAULT_LOCATION_BUTTON;
                 button_data->fake_root = TRUE;
