@@ -507,7 +507,8 @@ caja_window_zoom_to_default (CajaWindow *window)
 static guint
 get_max_forced_height (GdkScreen *screen)
 {
-    return (HeightOfScreen (gdk_x11_screen_get_xscreen (screen)) * 90) / 100;
+    gint scale = gdk_window_get_scale_factor (gdk_screen_get_root_window (screen));
+    return (HeightOfScreen (gdk_x11_screen_get_xscreen (screen)) / scale * 90) / 100;
 }
 
 /* Code should never force the window wider than this size.
@@ -516,7 +517,8 @@ get_max_forced_height (GdkScreen *screen)
 static guint
 get_max_forced_width (GdkScreen *screen)
 {
-    return (WidthOfScreen (gdk_x11_screen_get_xscreen (screen)) * 90) / 100;
+    gint scale = gdk_window_get_scale_factor (gdk_screen_get_root_window (screen));
+    return (WidthOfScreen (gdk_x11_screen_get_xscreen (screen)) / scale * 90) / 100;
 }
 
 /* This must be called when construction of CajaWindow is finished,
