@@ -115,19 +115,22 @@ icon_container_set_workarea (CajaIconContainer *icon_container,
 {
     int left, right, top, bottom;
     int screen_width, screen_height;
+    int scale;
     int i;
 
     left = right = top = bottom = 0;
 
-    screen_width  = WidthOfScreen (gdk_x11_screen_get_xscreen (screen));
-    screen_height = HeightOfScreen (gdk_x11_screen_get_xscreen (screen));
+    scale = gdk_window_get_scale_factor (gdk_screen_get_root_window (screen));
+
+    screen_width  = WidthOfScreen (gdk_x11_screen_get_xscreen (screen)) / scale;
+    screen_height = HeightOfScreen (gdk_x11_screen_get_xscreen (screen)) / scale;
 
     for (i = 0; i < n_items; i += 4)
     {
-        int x      = workareas [i];
-        int y      = workareas [i + 1];
-        int width  = workareas [i + 2];
-        int height = workareas [i + 3];
+        int x      = workareas [i] / scale;
+        int y      = workareas [i + 1] / scale;
+        int width  = workareas [i + 2] / scale;
+        int height = workareas [i + 3] / scale;
 
         if ((x + width) > screen_width || (y + height) > screen_height)
             continue;
@@ -389,10 +392,12 @@ realized_callback (GtkWidget *widget, FMDesktopIconView *desktop_icon_view)
     GdkWindow *root_window;
     GdkScreen *screen;
     GtkAllocation allocation;
+    gint scale;
 
     g_return_if_fail (desktop_icon_view->details->root_window == NULL);
 
     screen = gtk_widget_get_screen (widget);
+    scale = gtk_widget_get_scale_factor (widget);
 
     /* Ugly HACK for the problem that the views realize at the
      * wrong size and then get resized. (This is a problem with
@@ -402,8 +407,8 @@ realized_callback (GtkWidget *widget, FMDesktopIconView *desktop_icon_view)
      */
     allocation.x = 0;
     allocation.y = 0;
-    allocation.width = WidthOfScreen (gdk_x11_screen_get_xscreen (screen));
-    allocation.height = HeightOfScreen (gdk_x11_screen_get_xscreen (screen));
+    allocation.width = WidthOfScreen (gdk_x11_screen_get_xscreen (screen)) / scale;
+    allocation.height = HeightOfScreen (gdk_x11_screen_get_xscreen (screen)) / scale;
     gtk_widget_size_allocate (GTK_WIDGET(get_icon_container(desktop_icon_view)),
                               &allocation);
 
